==> haskell-random-shuffle-0.0.4-206-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-shuffle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 random-shuffle
version:              0.0.4
visibility:           public
id:                   random-shuffle-0.0.4-D41qZPKqb7U6NWx3YV9CRP
key:                  random-shuffle-0.0.4-D41qZPKqb7U6NWx3YV9CRP
license:              BSD-3-Clause
copyright:
    Oleg Kiselyov 2001
    Manlio Perillo 2009

maintainer:           Manlio Perillo <manlio.perillo@gmail.com>
author:               Oleg Kiselyov, Manlio Perillo, Andras Slemmer
stability:            Beta
synopsis:             Random shuffle implementation.
description:
    Random shuffle implementation, on immutable lists.
    Based on `perfect shuffle'\'' implementation by Oleg Kiselyov,
    available on http://okmij.org/ftp/Haskell/perfect-shuffle.txt

category:             System
abi:                  2b73c3e02689ea5e203c02aaad4ebb09
exposed:              True
exposed-modules:      System.Random.Shuffle
import-dirs:          /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-shuffle
hs-libraries:         HSrandom-shuffle-0.0.4-D41qZPKqb7U6NWx3YV9CRP
depends:
    MonadRandom-0.6.2-HBSdax0qPtuKCHCffRmbKG base-4.17.2.1
    random-1.2.1.2-7EfGGurDIwzGPzdRKPRaLg

haddock-interfaces:
    /usr/share/doc/haskell-random-shuffle/html/random-shuffle.haddock

haddock-html:         /usr/share/doc/haskell-random-shuffle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-random-shuffle-0.0.4-207-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-shuffle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 random-shuffle
version:              0.0.4
visibility:           public
id:                   random-shuffle-0.0.4-Be8GOrsTVdMKYMxqWWULEe
key:                  random-shuffle-0.0.4-Be8GOrsTVdMKYMxqWWULEe
license:              BSD-3-Clause
copyright:
    Oleg Kiselyov 2001
    Manlio Perillo 2009

maintainer:           Manlio Perillo <manlio.perillo@gmail.com>
author:               Oleg Kiselyov, Manlio Perillo, Andras Slemmer
stability:            Beta
synopsis:             Random shuffle implementation.
description:
    Random shuffle implementation, on immutable lists.
    Based on `perfect shuffle'\'' implementation by Oleg Kiselyov,
    available on http://okmij.org/ftp/Haskell/perfect-shuffle.txt

category:             System
abi:                  f1ade0619ffd2581cd59b678d51edada
exposed:              True
exposed-modules:      System.Random.Shuffle
import-dirs:          /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/random-shuffle-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-shuffle
hs-libraries:         HSrandom-shuffle-0.0.4-Be8GOrsTVdMKYMxqWWULEe
depends:
    MonadRandom-0.6.2-H9wVusHui0X1mqhcdhqVaf base-4.17.2.1
    random-1.2.1.2-3WH3fpxRON0BXsBQRmhDIT

haddock-interfaces:
    /usr/share/doc/haskell-random-shuffle/html/random-shuffle.haddock

haddock-html:         /usr/share/doc/haskell-random-shuffle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
